==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-input/lxqt-config-input_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Intermitência do cursor:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teclado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Reproduzir um som se ocorrer um erro de teclado</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Repetição de caracteres</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Longa</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Atraso de repetição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Curto</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Intervalo de repetição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Digite algo na caixa abaixo para testar o teclado</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Ativar NumLock ao iniciar a sessão</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Disposição do teclado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Disposição</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Variante</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>subir</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>descer</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Modelo do teclado:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Teclas para alterar a disposição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: se estiver a utilizar um &lt;span style=&quot; font-weight:600;&quot;&gt;método de introdução&lt;/span&gt;, tal como IBus, uim, fcitx ou gcin, as alterações aqui efetuadas &lt;span style=&quot; font-weight:600;&quot;&gt;poderão não funcionar&lt;/span&gt;, uma vez que serão substituídas pelos métodos de introdução utilizados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <source>Input Device Preferences</source>
        <translation>Preferências de dispositivos</translation>
    </message>
    <message>
        <source>Motion</source>
        <translation>Movimento</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Muito rápido</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <source>Sensitivity:</source>
        <translation>Sensibilidade:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Acceleration:</source>
        <translation>Aceleração:</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Canhoto (inverter botões do rato)</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <source>Character Repeat</source>
        <translation>Repetição de caracteres</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Longa</translation>
    </message>
    <message>
        <source>Repeat delay:</source>
        <translation>Atraso de repetição:</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Curto</translation>
    </message>
    <message>
        <source>Repeat interval:</source>
        <translation>Intervalo de repetição:</translation>
    </message>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Digite algo na caixa abaixo para testar o teclado</translation>
    </message>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Reproduzir um som se ocorrer um erro de teclado</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Teclado</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rato&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Movimento</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Muito rápido</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Sensibilidade:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Aceleração:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Intervalo do duplo clique:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Roda do rato desloca:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Canhoto (inverter botões do rato)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Ativar itens com um clique</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="34"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Definições do teclado e do rato</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="39"/>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="44"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="47"/>
        <source>Keyboard</source>
        <translation>Teclado</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Keyboard Layout</source>
        <translation>Disposição do teclado</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Selecione uma disposição</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Disposição do teclado</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Variante</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-input/lxqt-config-input_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../../../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Intermitência do cursor:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teclado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Reproduzir um som se ocorrer um erro de teclado</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Repetição de caracteres</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="79"/>
        <location filename="../../../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Longa</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Atraso de repetição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="115"/>
        <location filename="../../../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Curto</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Intervalo de repetição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Digite algo na caixa abaixo para testar o teclado</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="150"/>
        <location filename="../../../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Ativar NumLock ao iniciar a sessão</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Disposição do teclado&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Disposição</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Variante</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="77"/>
        <source>up</source>
        <translation>subir</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="84"/>
        <source>down</source>
        <translation>descer</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Modelo do teclado:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Teclas para alterar a disposição:</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../../../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: se estiver a utilizar um &lt;span style=&quot; font-weight:600;&quot;&gt;método de introdução&lt;/span&gt;, tal como IBus, uim, fcitx ou gcin, as alterações aqui efetuadas &lt;span style=&quot; font-weight:600;&quot;&gt;poderão não funcionar&lt;/span&gt;, uma vez que serão substituídas pelos métodos de introdução utilizados.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <source>Input Device Preferences</source>
        <translation type="vanished">Preferências de dispositivos</translation>
    </message>
    <message>
        <source>Motion</source>
        <translation type="vanished">Movimento</translation>
    </message>
    <message>
        <source>High</source>
        <translation type="vanished">Muito rápido</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="vanished">Rápido</translation>
    </message>
    <message>
        <source>Sensitivity:</source>
        <translation type="vanished">Sensibilidade:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="vanished">Baixa</translation>
    </message>
    <message>
        <source>Acceleration:</source>
        <translation type="vanished">Aceleração:</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation type="vanished">Lenta</translation>
    </message>
    <message>
        <source>0</source>
        <translation type="vanished">0</translation>
    </message>
    <message>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation type="vanished">Canhoto (inverter botões do rato)</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="vanished">Rato</translation>
    </message>
    <message>
        <source>Character Repeat</source>
        <translation type="vanished">Repetição de caracteres</translation>
    </message>
    <message>
        <source>Long</source>
        <translation type="vanished">Longa</translation>
    </message>
    <message>
        <source>Repeat delay:</source>
        <translation type="vanished">Atraso de repetição:</translation>
    </message>
    <message>
        <source>Short</source>
        <translation type="vanished">Curto</translation>
    </message>
    <message>
        <source>Repeat interval:</source>
        <translation type="vanished">Intervalo de repetição:</translation>
    </message>
    <message>
        <source>Type in the following box to test your keyboard settings</source>
        <translation type="vanished">Digite algo na caixa abaixo para testar o teclado</translation>
    </message>
    <message>
        <source>Beep when there is an error of keyboard input</source>
        <translation type="vanished">Reproduzir um som se ocorrer um erro de teclado</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation type="vanished">Teclado</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../../../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rato&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Movimento</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Muito rápido</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Sensibilidade:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Aceleração:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="116"/>
        <location filename="../../../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Intervalo do duplo clique:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Roda do rato desloca:</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Canhoto (inverter botões do rato)</translation>
    </message>
    <message>
        <location filename="../../../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Ativar itens com um clique</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="46"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Definições do teclado e do rato</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="51"/>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="56"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="59"/>
        <source>Keyboard</source>
        <translation>Teclado</translation>
    </message>
    <message>
        <location filename="../../../lxqt-config-input.cpp" line="63"/>
        <source>Keyboard Layout</source>
        <translation>Disposição do teclado</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Selecione uma disposição</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Disposição do teclado</translation>
    </message>
    <message>
        <location filename="../../../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Variante</translation>
    </message>
</context>
</TS>
